==> Botan-1.4.2.tgz: Botan-1.4.2/src/oids.cpp <==
/*************************************************
* OID Registry Source File                       *
* (C) 1999-2004 The Botan Project                *
*************************************************/

#include <botan/oids.h>
#include <botan/exceptn.h>
#include <botan/mutex.h>
#include <map>

namespace Botan {

namespace OIDS {

namespace {

std::map<OID, std::string> oid_to_str;
std::map<std::string, OID> str_to_oid;
Mutex* oid_mutex = 0;

}

/*************************************************
* Register an OID to string mapping              *
*************************************************/
void add_oid(const OID& oid, const std::string& name)
   {
   initialize_mutex(oid_mutex);
   Mutex_Holder lock(oid_mutex);

   if(oid_to_str.find(oid) == oid_to_str.end())
      oid_to_str[oid] = name;
   if(str_to_oid.find(name) == str_to_oid.end())
      str_to_oid[name] = oid;
   }

/*************************************************
* Do an OID to string lookup                     *
*************************************************/
std::string lookup(const OID& oid)
   {
   initialize_mutex(oid_mutex);
   Mutex_Holder lock(oid_mutex);

   std::map<OID, std::string>::const_iterator info = oid_to_str.find(oid);
   if(info == oid_to_str.end())
      return oid.as_string();
   return info->second;
   }

/*************************************************
* Do a string to OID lookup                      *
*************************************************/
OID lookup(const std::string& name)
   {
   initialize_mutex(oid_mutex);
   Mutex_Holder lock(oid_mutex);

   std::map<std::string, OID>::const_iterator info = str_to_oid.find(name);
   if(info == str_to_oid.end())
      throw Lookup_Error("No known OID for " + name);
   return info->second;
   }

/*************************************************
* Check to see if an OID exists in the table     *
*************************************************/
bool have_oid(const std::string& name)
   {
   initialize_mutex(oid_mutex);
   Mutex_Holder lock(oid_mutex);

   return (str_to_oid.find(name) != str_to_oid.end());
   }

}

}

==> Botan-1.5.7.tgz: Botan-1.5.7/src/oids.cpp <==
/*************************************************
* OID Registry Source File                       *
* (C) 1999-2006 The Botan Project                *
*************************************************/

#include <botan/oids.h>
#include <botan/libstate.h>

namespace Botan {

namespace OIDS {

/*************************************************
* Register an OID to string mapping              *
*************************************************/
void add_oid(const OID& oid, const std::string& name)
   {
   const std::string oid_str = oid.as_string();

   if(!global_state().option_set("oid2str", oid_str))
      global_state().set_option("oid2str", oid_str, name);
   if(!global_state().option_set("str2oid", name))
      global_state().set_option("str2oid", name, oid_str);
   }

/*************************************************
* Do an OID to string lookup                     *
*************************************************/
std::string lookup(const OID& oid)
   {
   return global_state().get_option("oid2str", oid.as_string());
   }

/*************************************************
* Do a string to OID lookup                      *
*************************************************/
OID lookup(const std::string& name)
   {
   return OID(global_state().get_option("str2oid", name));
   }

/*************************************************
* Check to see if an OID exists in the table     *
*************************************************/
bool have_oid(const std::string& name)
   {
   return global_state().option_set("str2oid", name);
   }

}

}
